/*
 * File:	message.c
 * 
 * Author:	Ulli Horlacher (framstag@rus.uni-stuttgart.de)
 * 
 * History:	11 Aug 95   Framstag	initial version
 *           	 1 Sep 95   Framstag	added global variable prg
 * 
 * VMS-like information, warning and error message routine.
 * 
 * This file is covered by the GNU General Public License
 */


#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>


#include "message.h"

/*
 * message - print information, warning and error messages on stderr
 *           ( shameless plug from VMS :-) )
 * 
 * INPUT:  cmd		- command or programm which sends message
 *         severity	- severity of message
 *         text		- text of message
 * 
 * exit program on a fatal 'F' error
 */
void message(char *cmd, const char severity, const char *text) {
  char *facility;	/* facility id */
  extern char *prg;	/* name of the game */

  /* no cmd? then use global variable prg */
  if (*cmd==0) {
    cmd=prg;
  }
    
  /* strip off path */
  facility = strrchr(cmd,'/');
  if (!facility) 
    facility = cmd; 
  else 
    facility++;

  /* print the message */
  fprintf(stderr,"%%%s-%c, %s",facility,severity,text);
  
  /* on error print the internal error message, too */
  if ((severity == 'E' || severity == 'F') && errno) 
    fprintf(stderr," : %s",strerror(errno));
  fprintf(stderr,"\n");
  
  /* exit on a fatal error */
  if (severity == 'F') exit(1);
}
